.. _GIF:

GIF
###

Data komt van documentatie bij de FDA, zie http://www.accessdata.fda.gov/scripts/cder/daf/
Type een medicijn naam in, click "Approval Date(s) and History, Letters, Labels, Reviews" en download de label.

Zyprexa:

| Oral LDLO (man): 7067 ug/kg
| Oral TDLO (woman): 400 ug/kg

Clozapine:

| Oral TDLO (man): 27 mg/kg/13D (intermittent)
| Oral TDLO (woman): 20 mg/kg

Caffeine:

| LDL [Human] 192mg/kg
| LDL [Woman] 400 mg/kg

Orap:

| LDL [Human] - Route: Oral Dose: 192mg/kg
| LDL [Woman] - Route: Oral; Dose; 400 mg/kg

Fuoxetine Hydrochloride:

| Oral (man) TDLo: 3.73 mg/kg/24h - I *

Paroxetine:

| Oral TDLO (man): 3654 μg/kg/14D (intermittent)
| Oral TDLO (man): 625 μg/kg

Citalopram:

| Oral TDLO (man): 35.3 mg/kg

Cannibidiol:

| Oral TDLo (human): 5.63 mg/kg;

